@@ -14,7 +14,8 @@ labelgjk <- NULL
     pj <- apply(X/sum(X), 2, sum)
     pk <- apply(X/sum(X), 3, sum)
     S <- switch(ca3type, "CA3" = ca3basic(X, p, q, r),  "NSCA3" = 
-                    nsca3basic(X, p, q, r),"OCA3" = oca3basic(X, p, q, r,norder=norder))
+                    nsca3basic(X, p, q, r),"OCA3" = oca3basic(X, p, q, r,norder=norder),
+                "ONSCA3" = onsca3basic(X, p, q, r,norder=norder))
      ######################################################################################
     #                                                                                                                                                                                                          #
     # Defines the analysis to be performed  for nominal variables- CA3 or NSCA3 -for ordinal variables OCA3 -ONSCA3    #
@@ -24,21 +25,36 @@ labelgjk <- NULL
     #    S <- ca3basic(X, p, q, r)
         pi <- apply(X/sum(X), 1, sum)
         index3 <- chi3(X)$z
+firstdim<-1
+lastdim<-2
     } 
         if(ca3type == "OCA3"){
       #  S <- oca3basic(X, p, q, r)
         pi <- apply(X/sum(X), 1, sum)
 chi2res<-chi3ordered(X)
 #print(chi2res)
-        index3 <- chi3ordered(X)$z
+        index3 <- chi3ordered(X)$zijk
+firstdim<-2
+lastdim<-3
 #browser()   
  } 
 if(ca3type == "NSCA3") {
      #   S <- nsca3basic(X, p, q, r)
         index3 <- tau3(X)$z
         pi <- rep(1, ni)
+firstdim<-1
+lastdim<-2
     }
-    
+    if(ca3type == "ONSCA3"){
+      #  S <- oca3basic(X, p, q, r)
+      pi <- rep(1, ni)
+      #tauMres<-tau3ordered(X)
+      #print(chi2res)
+      index3 <- tau3ordered(X)$zijk
+firstdim<-2
+lastdim<-3
+      #browser()   
+    } 
 ####################################################################
     #                                                                  #
     # Calculation of coordinates  for CA3 and NSCA3                    #
@@ -79,9 +95,9 @@ productfigjk <- fiStandard %*% t(gjk)
     ####################################################################
     inertia <- sum(S$xs^2)
     inertiapc0 <- (S$g^2/inertia*100)
-    inertiaRSS <- (inertia-sum(S$g^2))*n
- inertiapc1coltub <- apply(inertiapc0,1,sum)  
-inertiapc2row <- c(apply(inertiapc0,c(2,3),sum))  
+    inertiaRSS <- (inertia-sum(S$g^2))
+ inertiacoltub <- apply(inertiapc0,1,sum)  
+inertiarow <- c(apply(inertiapc0,c(2,3),sum))  
  #   ca3corporateresults<-new("ca3corporateresults", DataMatrix = X, xs = 
  #                                S$xs, xhat = S$xhat, nxhat2 = S$nxhat2, prp = S$prp, a=S$a,b=S$b,cc=S$cc,
 #fi = fi, fiStandard= fiStandard, gjk = gjk,gjkStandard=gjkStandard, rows = ni, cols = nj, tubes = nk, flabels = 
@@ -96,10 +112,10 @@ ca3corporateresults<-list(DataMatrix = X, xs =
                                  S$xs, xhat = S$xhat, nxhat2 = S$nxhat2, prp = S$prp, a=S$a,b=S$b,cc=S$cc,
 fi = fi, fiStandard= fiStandard, gjk = gjk,gjkStandard=gjkStandard, rows = ni, cols = nj, tubes = nk, flabels = 
                                  labelfi, glabels = labelgjk, maxaxes = maxaxes, 
-                             inertia = inertia,inertiaRSS = inertiaRSS, inertiapc0 = inertiapc0, inertiacoltub = inertiapc1coltub,inertiarow=inertiapc2row, 
+                             inertia = inertia, inertiaRSS=inertiaRSS, inertiapc = inertiapc0, inertiacoltub = inertiacoltub,inertiarow=inertiarow, 
                              iproduct = productfigjk, g = S$g, index3 = index3, ca3type = 
-                                 ca3type, iteration = S$iteration)
+                                 ca3type, iteration = S$iteration,firstaxis=firstdim,lastaxis=lastdim)
  
 class(ca3corporateresults)<-"CA3variants"
-return(ca3corporateresults)
+invisible(return(ca3corporateresults))
 }
